Continued (first wave of migration):
authorRoland Häder <roland@mxchange.org>
Mon, 1 Jan 2018 02:45:25 +0000 (03:45 +0100)
committerRoland Häder <roland@mxchange.org>
Mon, 1 Jan 2018 02:45:25 +0000 (03:45 +0100)
- updated core framework to latest commit (with namespaces!)
- removed discouraged ?> tag closer

Signed-off-by: Roland Häder <roland@mxchange.org>
129 files changed:
application/city/class_ApplicationHelper.php
application/city/classes/actions/class_
application/city/classes/actions/class_BaseCityAction.php
application/city/classes/actions/html/city/class_HtmlCityLoginCityMapAction.php
application/city/classes/actions/html/class_HtmlCityLoginGovernmentAction.php
application/city/classes/actions/html/class_HtmlCityLoginLogoutAction.php
application/city/classes/actions/html/class_HtmlCityLoginProfileAction.php
application/city/classes/actions/html/class_HtmlCityLoginStatusProblemAction.php
application/city/classes/actions/html/class_HtmlCityLoginWelcomeAction.php
application/city/classes/city_daemon/class_
application/city/classes/city_daemon/class_BaseCityDaemon.php
application/city/classes/city_daemon/default/class_SimulationDefaultCityDaemon.php
application/city/classes/class_
application/city/classes/class_Base
application/city/classes/class_BaseCitySystem.php
application/city/classes/commands/console/class_CityConsoleDaemonCommand.php
application/city/classes/commands/html/class_CityHtmlCityGuestLoginCommand.php
application/city/classes/commands/html/class_CityHtmlCityMapCommand.php
application/city/classes/commands/html/class_CityHtmlCityRegisterCommand.php
application/city/classes/commands/html/class_CityHtmlCityUserLoginCommand.php
application/city/classes/commands/html/class_CityHtmlConfirmCommand.php
application/city/classes/commands/html/class_CityHtmlDoFormCommand.php
application/city/classes/commands/html/class_CityHtmlHomeCommand.php
application/city/classes/commands/html/class_CityHtmlLoginAreaCommand.php
application/city/classes/commands/html/class_CityHtmlLoginCommand.php
application/city/classes/commands/html/class_CityHtmlLoginFailedCommand.php
application/city/classes/commands/html/class_CityHtmlLogoutCommand.php
application/city/classes/commands/html/class_CityHtmlRegisterCommand.php
application/city/classes/commands/html/class_CityHtmlResendLinkCommand.php
application/city/classes/commands/html/class_HtmlLogoutDoneCommand.php
application/city/classes/controller/console/class_CityConsoleDefaultNewsController.php
application/city/classes/controller/html/class_CityHtmlConfirmController.php
application/city/classes/controller/html/class_CityHtmlDefaultNewsController.php
application/city/classes/controller/html/class_CityHtmlLoginController.php
application/city/classes/controller/html/class_CityHtmlLoginFailedController.php
application/city/classes/controller/html/class_CityHtmlLogoutController.php
application/city/classes/controller/html/class_CityHtmlLogoutDoneController.php
application/city/classes/controller/html/class_CityHtmlRegisterController.php
application/city/classes/controller/html/form/class_CityHtmlDoFormController.php
application/city/classes/controller/html/login/class_CityHtmlLoginAreaController.php
application/city/classes/database/frontend/city/class_CityInformationDatabaseWrapper.php
application/city/classes/database/frontend/city_entities/districts/class_CityDistrictsDatabaseWrapper.php
application/city/classes/database/frontend/city_entities/lots/class_CityLotsDatabaseWrapper.php
application/city/classes/database/frontend/city_entities/sections/class_CitySectionsDatabaseWrapper.php
application/city/classes/database/frontend/game_options/class_CityGameOptionsDatabaseWrapper.php
application/city/classes/database/frontend/region/class_RegionInformationDatabaseWrapper.php
application/city/classes/database/frontend/region_map/class_RegionMapDatabaseWrapper.php
application/city/classes/factories/city_daemon/class_CityDaemonFactory.php
application/city/classes/factories/manager/class_ManagerFactory.php
application/city/classes/factories/states/city/class_CityStateFactory.php
application/city/classes/filter/bootstrap/city_daemon/class_CityDaemonBootstrap
application/city/classes/filter/bootstrap/city_daemon/class_CityDaemonBootstrapExtraBootstrappingFilter.php
application/city/classes/filter/bootstrap/class_CityDaemonBootstrap
application/city/classes/filter/bootstrap/init/class_CityDaemonBootstrapInitDaemonFilter.php
application/city/classes/filter/city_daemon/class_CityDaemon
application/city/classes/filter/city_daemon/class_CityDaemonInitializationFilter.php
application/city/classes/filter/city_daemon/class_CityDaemonPhpRequirementsFilter.php
application/city/classes/filter/city_daemon/class_CityDaemonWelcomeTeaserFilter.php
application/city/classes/filter/class_
application/city/classes/filter/class_BaseCityFilter.php
application/city/classes/filter/shutdown/city/class_CityDaemonShutdown
application/city/classes/filter/shutdown/city/class_CityDaemonShutdownCityFilter.php
application/city/classes/filter/shutdown/city/class_CityDaemonShutdownTaskHandlerFilter.php
application/city/classes/filter/task/city_daemon/class_CityDaemonTaskHandlerInitializerFilter.php
application/city/classes/filter/verifier/class_CityNameVerifierFilter.php
application/city/classes/login/class_CityGuestLogin.php
application/city/classes/login/class_CityUserLogin.php
application/city/classes/manager/city/class_CityManager.php
application/city/classes/manager/city_entities/districts/class_CityDistrictsManager.php
application/city/classes/manager/city_entities/lots/class_CityLotsManager.php
application/city/classes/manager/city_entities/sections/class_CitySectionsManager.php
application/city/classes/manager/class_
application/city/classes/manager/class_BaseManager.php
application/city/classes/manager/game/class_GameManager.php
application/city/classes/manager/region/class_RegionManager.php
application/city/classes/manager/region/class_RegionMapManager.php
application/city/classes/menu/class_City
application/city/classes/menu/class_CityConfirmMenu.php
application/city/classes/menu/class_CityHomeMenu.php
application/city/classes/menu/class_CityLoginAreaMenu.php
application/city/classes/menu/class_CityLoginFailedMenu.php
application/city/classes/menu/class_CityLoginMenu.php
application/city/classes/menu/class_CityLogoutMenu.php
application/city/classes/menu/class_CityRegisterMenu.php
application/city/classes/menu/class_CityStatusMenu.php
application/city/classes/menu/government/class_CityGovernmentFailedAreaMenu.php
application/city/classes/resolver/command/console/class_CityConsoleCommandResolver.php
application/city/classes/resolver/command/html/class_CityHtmlCommandResolver.php
application/city/classes/resolver/controller/console/class_CityConsoleControllerResolver.php
application/city/classes/resolver/controller/html/class_CityHtmlControllerResolver.php
application/city/classes/resolver/controller/image/class_CityImageControllerResolver.php
application/city/classes/states/city/active/class_CityActiveState.php
application/city/classes/states/city/class_
application/city/classes/states/city/class_BaseCityState.php
application/city/classes/states/city/init/class_CityInitState.php
application/city/classes/tasks/class_BaseCityTask.php
application/city/classes/tasks/daemon/building/class_CityDaemonBuildingGrowthTask.php
application/city/classes/tasks/daemon/class_CityDaemon
application/city/classes/tasks/daemon/household/class_CityDaemonHouseholdGrowthTask.php
application/city/classes/tasks/daemon/map_expander/class_CityDaemonMapExpanderTask.php
application/city/config-local.php-dist
application/city/config.php
application/city/data.php
application/city/debug.php
application/city/exceptions.php
application/city/init.php
application/city/interfaces/database/frontend/city/class_CityInformationWrapper.php
application/city/interfaces/database/frontend/city_entities/districts/class_CityDistrictsWrapper.php
application/city/interfaces/database/frontend/city_entities/lots/class_CityLotsWrapper.php
application/city/interfaces/database/frontend/city_entities/sections/class_CitySectionsWrapper.php
application/city/interfaces/database/frontend/game_options/class_CityGameOptionsWrapper.php
application/city/interfaces/database/frontend/region/class_RegionInformationWrapper.php
application/city/interfaces/database/frontend/region/class_RegionMapWrapper.php
application/city/interfaces/helper/city/class_CityHelper.php
application/city/interfaces/manager/city/class_ManageableCity.php
application/city/interfaces/manager/city_entities/class_ManageableCityEntities.php
application/city/interfaces/manager/city_entities/districts/class_ManageableCityDistricts.php
application/city/interfaces/manager/city_entities/lots/class_ManageableCityLots.php
application/city/interfaces/manager/city_entities/sections/class_ManageableCitySections.php
application/city/interfaces/manager/class_Manageable.php
application/city/interfaces/manager/region/class_ManageableRegion.php
application/city/interfaces/manager/region/class_ManageableRegionMap.php
application/city/loader.php
application/city/starter.php
application/city/templates/image/code_captcha.img
application/city/templates/image/emergency_exit.img
core
inc [deleted symlink]
index.php

index fa8d88d87e8bbe51028083160f4e6860eea8d45f..78e01ba1e98fe98e3ecbd37346c4617eef4cabc9 100644 (file)
@@ -1,4 +1,17 @@
 <?php
+// Must be this namespace, else the launcher cannot find the class.
+namespace Org\Mxchange\CoreFramework\Helper\Application;
+
+// Import framework stuff
+use Org\Mxchange\CoreFramework\Bootstrap\FrameworkBootstrap;
+use Org\Mxchange\CoreFramework\Factory\ObjectFactory;
+use Org\Mxchange\CoreFramework\Loader\ClassLoader;
+use Org\Mxchange\CoreFramework\Manager\ManageableApplication;
+use Org\Mxchange\CoreFramework\Object\BaseFrameworkSystem;
+use Org\Mxchange\CoreFramework\Registry\Registerable;
+use Org\Mxchange\CoreFramework\Registry\Registry;
+use Org\Mxchange\CoreFramework\Template\CompileableTemplate;
+
 /**
  * A class holding general data about the application and some methods for
  * the management including the entry point.
@@ -22,7 +35,7 @@
  *
  * @author             Roland Haeder <webmaster@shipsimu.org>
  * @version            0.0
- * @copyright  Copyright (c) 2015, 2016 City Developer Team
+ * @copyright  Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 City Developer Team
  * @license            GNU GPL 3.0 or any newer version
  *
  * This program is free software: you can redistribute it and/or modify
@@ -144,37 +157,54 @@ class ApplicationHelper extends BaseFrameworkSystem implements ManageableApplica
        }
 
        /**
-        * Launches the test suite
+        * 1) Setups application data
         *
         * @return      void
         */
-       public final function entryPoint () {
-               // Set this application in registry
-               Registry::getRegistry()->addInstance('app', $this);
+       public function setupApplicationData () {
+               // Set all application data
+               $this->setAppName('Unit tests and more');
+               $this->setAppVersion('0.0.0');
+               $this->setAppShortName('tests');
+       }
 
-               // Default response is console
-               $response = self::getResponseTypeFromSystem();
-               $responseType = self::getResponseTypeFromSystem();
+       /**
+        * 2) Does initial stuff before starting the application
+        *
+        * @return      void
+        */
+       public function initApplication () {
+               // Get config instance
+               $cfg = FrameworkBootstrap::getConfigurationInstance();
 
-               // Create a new request object
-               $requestInstance = ObjectFactory::createObjectByName(self::convertToClassName($response) . 'Request');
+               // Initialize output system
+               self::createDebugInstance('ApplicationHelper');
 
-               // Remember request instance here
-               $this->setRequestInstance($requestInstance);
+               /*
+                * This application needs a database connection then simply call init
+                * method.
+                */
+               FrameworkBootstrap::initDatabaseInstance();
 
-               // Do we have another response?
-               if ($requestInstance->isRequestElementSet('request')) {
-                       // Then use it
-                       $response = strtolower($requestInstance->getRequestElement('request'));
-                       $responseType = $response;
-               } // END - if
+               // Register core tests
+               ClassLoader::registerTestsPath('framework/main/tests');
 
-               // ... and a new response object
-               $responseClass = sprintf('%sResponse', self::convertToClassName($response));
-               $responseInstance = ObjectFactory::createObjectByName($responseClass, array($this));
+               // Register own tests
+               ClassLoader::registerTestsPath('application/tests/tests');
 
-               // Remember response instance here
-               $this->setResponseInstance($responseInstance);
+               // Scan for them now
+               ClassLoader::scanTestsClasses();
+       }
+
+       /**
+        * 3) Launches the application
+        *
+        * @return      void
+        */
+       public function launchApplication () {
+               // Get request/response instances
+               $requestInstance  = FrameworkBootstrap::getRequestInstance();
+               $responseInstance = FrameworkBootstrap::getResponseInstance();
 
                // Get the parameter from the request
                $commandName = $requestInstance->getRequestElement('command');
@@ -189,33 +219,26 @@ class ApplicationHelper extends BaseFrameworkSystem implements ManageableApplica
                } // END - if
 
                // Get a controller resolver
-               $resolverClass = self::convertToClassName($this->getAppShortName() . '_' . $responseType . '_controller_resolver');
+               $resolverClass = sprintf(
+                       'Org\Mxchange\CoreFramework\Tests\Resolver\Controller\%s',
+                       self::convertToClassName(sprintf(
+                               '%s_%s_controller_resolver',
+                               $this->getAppShortName(),
+                               FrameworkBootstrap::getRequestTypeFromSystem()
+                       ))
+               );
                $resolverInstance = ObjectFactory::createObjectByName($resolverClass, array($commandName, $this));
 
                // Get a controller instance as well
                $this->setControllerInstance($resolverInstance->resolveController());
 
-               // Initialize language system
-               $languageInstance = ObjectFactory::createObjectByConfiguredName('language_system_class');
-
-               // And set it here
-               $this->setLanguageInstance($languageInstance);
-
-               // Launch the game here
+               // Launch the test suite here
                $this->getControllerInstance()->handleRequest($requestInstance, $responseInstance);
 
                // -------------------------- Shutdown phase --------------------------
+               self::createDebugInstance(__CLASS__, __LINE__)->debugOutput('MAIN: Shutdown in progress ...');
                $this->getControllerInstance()->executeShutdownFilters($requestInstance, $responseInstance);
-       }
-
-       /**
-        * Assigns extra application-depending data
-        *
-        * @param       $templateInstance       An instance of a CompileableTemplate
-        * @return      void
-        * @todo        Nothing to add?
-        */
-       public function assignExtraTemplateData (CompileableTemplate $templateInstance) {
+               self::createDebugInstance(__CLASS__, __LINE__)->debugOutput('MAIN: Shutdown completed. (This is the last line.)');
        }
 
        /**
@@ -240,7 +263,16 @@ class ApplicationHelper extends BaseFrameworkSystem implements ManageableApplica
        public function buildMasterTemplateName () {
                return 'city_main';
        }
-}
 
-// [EOF]
-?>
+       /**
+        * Assigns extra application-depending data
+        *
+        * @param       $templateInstance       An instance of a CompileableTemplate
+        * @return      void
+        * @todo        Nothing to add?
+        */
+       public function assignExtraTemplateData (CompileableTemplate $templateInstance) {
+               $this->partialStub('Unfinished method. templateInstance=' . $templateInstance->__toString());
+       }
+
+}
index f8dc518a7e61f2cbccddce1ed1e54ee17071d7cd..a89fce5892af28cd2cedacc7963b35389222a637 100644 (file)
@@ -77,6 +77,3 @@ class ???Action extends BaseCityAction implements Commandable, Registerable {
                // Unfinished method
        }
 }
-
-// [EOF]
-?>
index 9408e5f44d20129ec3c6384ed7f974de670dddaa..6db25818446d3c5caefa464a50164cb9c8570f68 100644 (file)
@@ -57,6 +57,3 @@ class BaseCityAction extends BaseAction {
                // Unfinished method
        }
 }
-
-// [EOF]
-?>
index b45dcf46302bfcec4a2fe1fab4d46ee247c07473..730d68765caa54730f9bb19bcc0d86a3970bea9e 100644 (file)
@@ -74,6 +74,3 @@ class HtmlCityLoginCityMapAction extends BaseCityAction implements Commandable,
                // Unfinished method
        }
 }
-
-// [EOF]
-?>
index aba18b5ae6b5d90ad3327145f877fe66f1f21d5f..274766747398d00e5ca9b3ba98d3ff82a6143eee 100644 (file)
@@ -74,6 +74,3 @@ class HtmlCityLoginGovernmentAction extends BaseCityAction implements Commandabl
                // Unfinished method
        }
 }
-
-// [EOF]
-?>
index bd202c04d1c8932f1663ee961a60f53cc9f7c071..46a35d8e19b1adf0fa30f7b0dc112562ff2653b1 100644 (file)
@@ -76,6 +76,3 @@ class HtmlCityLoginLogoutAction extends BaseCityAction implements Commandable, R
                $controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_status_filter'));
        }
 }
-
-// [EOF]
-?>
index 21b919ea3510de3c239fb3d95c02e2e227ba6fa1..9acb5d3b68a8131e4657ab933b4ac5590d4bd0d8 100644 (file)
@@ -77,6 +77,3 @@ class HtmlCityLoginProfileAction extends BaseCityAction implements Commandable,
                $controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_status_filter'));
        }
 }
-
-// [EOF]
-?>
index e45545e201e88ad557542f5dc22cb037bb54f009..168d172c82bf4d1c896c64e5a6cd378ba60f7762 100644 (file)
@@ -77,6 +77,3 @@ class HtmlCityLoginStatusProblemAction extends BaseCityAction implements Command
                $controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_status_filter'));
        }
 }
-
-// [EOF]
-?>
index 38acd264ef48900de60350f7782c797552e16412..f3aee4e891fd2c0b1d430712cb22dd059e838884 100644 (file)
@@ -74,6 +74,3 @@ class HtmlCityLoginWelcomeAction extends BaseCityAction implements Commandable,
                // Unfinished method
        }
 }
-
-// [EOF]
-?>
index dd27a87e8cda0ca5b437dffedaebab42ed53cad8..be345955771ab504c1d02c809d10c59d07b4fd93 100644 (file)
@@ -93,6 +93,3 @@ class Simulation???CityDaemon extends BaseCity implements CityHelper, Registerab
                $this->partialStub('Please add some tasks or empty this method.');
        }
 }
-
-// [EOF]
-?>
index 1fe1d14757d61dd18b53d375bd2ebdbe93b253c2..45757a0218af73281a000f4134e84daa20392a9b 100644 (file)
@@ -263,6 +263,3 @@ class BaseCityDaemon extends BaseCitySystem implements Updateable, AddableCriter
                $sectionsInstance->expandMaps();
        }
 }
-
-// [EOF]
-?>
index 88a1c0da06d7f4f742afa55dbb42498bfa3003b9..759f05a425620c8010cf7d501661f3349b3921a5 100644 (file)
@@ -90,6 +90,3 @@ class SimulationDefaultCityDaemon extends BaseCityDaemon implements CityHelper,
                $this->partialStub('Please add some tasks or empty this method.');
        }
 }
-
-// [EOF]
-?>
index 6a4b9ad5df0819aa4955c2e701766a9ebc0ee5a5..81c984741c11aab3d191ac8d4132bf84d4ed4e69 100644 (file)
@@ -45,6 +45,3 @@ class ??? extends BaseCitySystem implements === {
                return $!!!Instance;
        }
 }
-
-// [EOF]
-?>
index a732a10efa75bcdaeaa9e7636a31a280ed44967b..75f09344721418f14d9bba96b28d984aa2ce577e 100644 (file)
@@ -33,6 +33,3 @@ class Base??? extends BaseCitySystem {
                parent::__construct($className);
        }
 }
-
-// [EOF]
-?>
index 79edc0d50e7edeb63eb655270390e0acf5c8165e..f4448a07cfee62e50d32ffd8ef2045ee5b38039f 100644 (file)
@@ -64,6 +64,3 @@ class BaseCitySystem extends BaseFrameworkSystem {
                $this->cityInstance = $cityInstance;
        }
 }
-
-// [EOF]
-?>
index 449363f1fee7aa7dcf185147b1320315425a83b2..de4e495e54690f52b3d25689c5fae7ac88510c57 100644 (file)
@@ -133,6 +133,3 @@ class CityConsoleDaemonCommand extends BaseCommand implements Commandable {
                $controllerInstance->addShutdownFilter(ObjectFactory::createObjectByConfiguredName('city_daemon_shutdown_city_filter'));
        }
 }
-
-// [EOF]
-?>
index f9ad3276d87fe0a487578de9f58e62f0a48240f9..e1d8d4a9fd5f605acd3706e63e73c086526c2a7d 100644 (file)
@@ -107,6 +107,3 @@ class CityHtmlCityGuestLoginCommand extends BaseCommand implements Commandable {
                $controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('captcha_guest_verifier_filter'));
        }
 }
-
-// [EOF]
-?>
index 381a9852e044ef8a7e2dd823659d50cb84cf69e1..ce56651ecfb49fd3b4799bfbfd98bd4e28219e3d 100644 (file)
@@ -102,6 +102,3 @@ class CityHtmlCityMapCommand extends BaseCommand implements Commandable {
                //$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('email_validator_filter'));
        }
 }
-
-// [EOF]
-?>
index c66be4e0337f79f71ab33e776e6ff5a5a14aa5b6..c555b10ace2791575d0fbed5c43ae3c1bebc7e14 100644 (file)
@@ -114,6 +114,3 @@ class CityHtmlCityRegisterCommand extends BaseCommand implements Commandable {
                $controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('birthday_register_verifier_filter'));
        }
 }
-
-// [EOF]
-?>
index 3f2580c6c8a373e3b06407bc443226bc69d7501d..02d30b91a5869797557b88c9e89e83de36bbdfbc 100644 (file)
@@ -119,6 +119,3 @@ class CityHtmlCityUserLoginCommand extends BaseCommand implements Commandable {
                $controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('captcha_user_verifier_filter'));
        }
 }
-
-// [EOF]
-?>
index fc48015f12475039f5637e0c5fb247d80595f248..40636c6682c0e15c9b3299ddebea776933e57e9d 100644 (file)
@@ -141,6 +141,3 @@ class CityHtmlConfirmCommand extends BaseCommand implements Commandable {
                // Empty for now
        }
 }
-
-// [EOF]
-?>
index 3ebfec549ca148e2565015f014c037e17a60f017..499d6044fd1ac24c9b6236d23223b43f50e2f9f3 100644 (file)
@@ -73,6 +73,3 @@ class CityHtmlDoFormCommand extends BaseCommand implements Commandable {
        }
 
 }
-
-// [EOF]
-?>
index 4b96d2a40d51e768177c4c075984454914bef461..77f6e73276fc7c6ab4dbf556bba6276e1e4986aa 100644 (file)
@@ -86,6 +86,3 @@ class CityHtmlHomeCommand extends BaseCommand implements Commandable {
                //$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('node_php_requirements_filter'));
        }
 }
-
-// [EOF]
-?>
index 27f9506728d786f81ed4f6433a0f64c143651336..60cab3f3e14428dadf619569ebd26d7c47249065 100644 (file)
@@ -198,6 +198,3 @@ class CityHtmlLoginAreaCommand extends BaseCommand implements Commandable {
                Registry::getRegistry()->addInstance('action', $actionInstance);
        }
 }
-
-// [EOF]
-?>
index e4a4446dbdf1fef16c670321b8031aa92d400d62..bd1327d1f42b734634d99ea0c91dfe9672f9c85c 100644 (file)
@@ -101,8 +101,10 @@ class CityHtmlLoginCommand extends BaseCommand implements Commandable, Registera
                // Set title
                $templateInstance->assignVariable('title', $this->getLanguageInstance()->getMessage('page_login_title'));
 
-               // Construct the menu in every command. We could do this in BaseCommand class. But this means
-               // *every* command has a navigation system and that is want we don't want.
+               /*
+                * Construct the menu in every command. We could do this in BaseCommand class. But this means
+                * *every* command has a navigation system and that is want we don't want.
+                */
                $menuInstance = ObjectFactory::createObjectByConfiguredName('login_menu_class', array($applicationInstance));
 
                // Render the menu
@@ -133,6 +135,3 @@ class CityHtmlLoginCommand extends BaseCommand implements Commandable, Registera
                // Empty for now
        }
 }
-
-// [EOF]
-?>
index c591d578516589cacd8bf212514d9c3006be8240..8bfcf4103a69219fc2516fcc2d86f351e8bab84b 100644 (file)
@@ -130,6 +130,3 @@ class CityHtmlLoginFailedCommand extends BaseCommand implements Commandable {
                // Empty for now
        }
 }
-
-// [EOF]
-?>
index 44042bc246c04be91ca5a3b2f25be3d5cf5febd7..cbf51972072a7c0c8c855933132c19f61fcf0f7b 100644 (file)
@@ -84,6 +84,3 @@ class CityHtmlLogoutCommand extends BaseCommand implements Commandable {
                // Empty for now
        }
 }
-
-// [EOF]
-?>
index 70f43fdca79fb2680623692df7881f0794b15f81..17f256debd589b8da47f38405f8858e5078fc9eb 100644 (file)
@@ -75,6 +75,3 @@ class CityHtmlRegisterCommand extends BaseCommand implements Commandable {
        public function addExtraFilters (Controller $controllerInstance, Requestable $requestInstance) {
        }
 }
-
-// [EOF]
-?>
index 47991bbc01130140ad9696c4adc19a8b1bc90e12..73e4f48d41bfce005e05820f718dff7f9e2b1942 100644 (file)
@@ -130,6 +130,3 @@ class CityHtmlResendLinkCommand extends BaseCommand implements Commandable {
                $controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_unconfirmed_filter'));
        }
 }
-
-// [EOF]
-?>
index 5f207705b2b79bfa73b4c5b0cb14f3f53342feb4..28f0d0fd53522e811bc1f719a3ae5d68d331f849 100644 (file)
@@ -130,6 +130,3 @@ class HtmlLogoutDoneCommand extends BaseCommand implements Commandable {
                // Empty for now
        }
 }
-
-// [EOF]
-?>
index e408d22b4ee2fbd12e86b7d670ef79428440fd7b..9379b5ef9154da35a82eecd3e7b11697ec8e8147 100644 (file)
@@ -130,6 +130,3 @@ class CityConsoleDefaultNewsController extends BaseController implements Control
                $this->executeFilters('activation', $requestInstance, $responseInstance);
        }
 }
-
-// [EOF]
-?>
index e2e4ead526398618041bdd0200485dffb6f8249e..be70e6ec1bfa70f2add8742d2ffae14cf0c009a8 100644 (file)
@@ -68,6 +68,3 @@ class CityHtmlConfirmController extends BaseController implements Controller {
                $this->executeGenericPrePostCommand($requestInstance, $responseInstance);
        }
 }
-
-// [EOF]
-?>
index b5742c27789728530986b0e2db8d40ff4b9616aa..709fd07ca1277ab264bc429e3ff0b318af3f874d 100644 (file)
@@ -70,6 +70,3 @@ class CityHtmlDefaultNewsController extends BaseController implements Controller
                $this->executeGenericPrePostCommand($requestInstance, $responseInstance);
        }
 }
-
-// [EOF]
-?>
index 3cd8b9d08a60609bdb5f9ef4cf3c5c1bba64292e..f155f676d1f82dae633c5666defd072832d8bedd 100644 (file)
@@ -68,6 +68,3 @@ class CityHtmlLoginController extends BaseController implements Controller {
                $this->executeGenericPrePostCommand($requestInstance, $responseInstance);
        }
 }
-
-// [EOF]
-?>
index 15400914fc96c178ed32129251aa3197e0c024ab..136f1fca6e1ca878bcf3e73364108c4441d78402 100644 (file)
@@ -75,6 +75,3 @@ class CityHtmlLoginFailedController extends BaseController implements Controller
                $responseInstance->flushBuffer();
        }
 }
-
-// [EOF]
-?>
index a3ae8cea873b8dff4f99a60bc5743af58f95980d..ce7e1dd2f404a8292312b961c75d13ca312da0ce 100644 (file)
@@ -82,6 +82,3 @@ class CityHtmlLogoutController extends BaseController implements Controller {
                $responseInstance->flushBuffer();
        }
 }
-
-// [EOF]
-?>
index 3c247555edc387bc2e4f437565ec8563eb3fe93b..a8f003139e45da8dc24ce4ea53df55df969339a1 100644 (file)
@@ -67,6 +67,3 @@ class CityHtmlLogoutDoneController extends BaseController implements Controller
                $this->executeGenericPrePostCommand($requestInstance, $responseInstance);
        }
 }
-
-// [EOF]
-?>
index ce1477cbd228bcd6ff361cb18cdb51ed53d6fb9b..1e81ca4cce8fd1efb627bbeb87af4e539bf982c6 100644 (file)
@@ -67,6 +67,3 @@ class CityHtmlRegisterController extends BaseController implements Controller {
                $this->executeGenericPrePostCommand($requestInstance, $responseInstance);
        }
 }
-
-// [EOF]
-?>
index 25cf6997aac4fea10303a769427231415344280a..efeb3e2570d24ea24fe0c18752535716caa9df72 100644 (file)
@@ -102,6 +102,3 @@ class CityHtmlDoFormController extends BaseController implements Controller {
                $responseInstance->flushBuffer();
        }
 }
-
-// [EOF]
-?>
index c9dfba081564f894e8d3d8f8692facfe2329df45..2b3e12361cbc0e2d5cbddc769f4a9eb6c9e1bf46 100644 (file)
@@ -82,6 +82,3 @@ class CityHtmlLoginAreaController extends BaseController implements Controller {
                $this->genericHanleRequestLoginAreaFailedRedirect($requestInstance, $responseInstance);
        }
 }
-
-// [EOF]
-?>
index e1a378fd4cd56151328c71d3bdf4db6d1796f8d2..c9f53a9cf82f849ebb517a8972e49ff568f1cbfa 100644 (file)
@@ -266,6 +266,3 @@ class CityInformationDatabaseWrapper extends BaseDatabaseWrapper implements City
                return $cityIds;
        }
 }
-
-// [EOF]
-?>
index e07f36f7a16a78f1ba41c6799fc951f10810b81f..246ef5b9ec7ce6ab403c40c0e0a225deec5a7981 100644 (file)
@@ -84,6 +84,3 @@ class CityDistrictsDatabaseWrapper extends BaseDatabaseWrapper implements CityDi
                return $isFound;
        }
 }
-
-// [EOF]
-?>
index 432534974218fac16be820bde53b7f36200ddd51..8563f1b569e19630a35821707585b455b734541a 100644 (file)
@@ -85,6 +85,3 @@ class CityLotsDatabaseWrapper extends BaseDatabaseWrapper implements CityLotsWra
                return $isFound;
        }
 }
-
-// [EOF]
-?>
index 7dc2b235e78e9f0c3ebcea3ddfb2355b09fed91d..9e2433ed4ff11e5b59b0386d27627bc4799ff06d 100644 (file)
@@ -263,6 +263,3 @@ class CitySectionsDatabaseWrapper extends BaseDatabaseWrapper implements CitySec
                self::createDebugInstance(__CLASS__)->debugOutput('[' . __METHOD__ . ':' . __LINE__ . ']: A total of ' . $totalSections . ' sections has been written for city id ' . $cityId . '.');
        }
 }
-
-// [EOF]
-?>
index c5492c0c816cda65d8ffffc4ece6dd22240f99d1..9eb329490e22d4c13d5133900aa7979c10dc5052 100644 (file)
@@ -56,6 +56,3 @@ class CityGameOptionsDatabaseWrapper extends BaseDatabaseWrapper implements City
                return $wrapperInstance;
        }
 }
-
-// [EOF]
-?>
index c55246fbbb1f411733947249907ca98c0ba37c74..46846955ab7e81c8593ab26805b0fa8294a0adef 100644 (file)
@@ -170,6 +170,3 @@ class RegionInformationDatabaseWrapper extends BaseDatabaseWrapper implements Re
                assert($this->ifRegionExists($regionName));
        }
 }
-
-// [EOF]
-?>
index 6a74449c9fb72b1c49e6afd3c3a78c658ff75f38..de3124578a71b41f0a676454bb7eb04c484c3a99 100644 (file)
@@ -98,6 +98,3 @@ class RegionMapDatabaseWrapper extends BaseDatabaseWrapper implements RegionMapW
                assert($this->ifRegionExists($regionName));
        }
 }
-
-// [EOF]
-?>
index fb039b87afda1baad7d8f956afce59e772ebd9ec..dc6b1d5da1f5e2c3bb9940ff60ea2e84ed7d48df 100644 (file)
@@ -84,6 +84,3 @@ class CityDaemonFactory extends ObjectFactory {
                return $cityInstance;
        }
 }
-
-// [EOF]
-?>
index 7a8e27895189dc5c9432f614df190510efcdb855..7f740a152a979c813b3423cc1a8a0b8119f644c0 100644 (file)
@@ -61,6 +61,3 @@ class ManagerFactory extends ObjectFactory {
                return $managerInstance;
        }
 }
-
-// [EOF]
-?>
index 1099f70b63f54673b21f1a9efb85df82ac66f88d..b564e08459a55b943cf0cb3cd456c6c5fb7bd0df 100644 (file)
@@ -62,6 +62,3 @@ class CityStateFactory extends ObjectFactory {
                return $stateInstance;
        }
 }
-
-// [EOF]
-?>
index 05e5541e5e5467c2fc9a29abea0b45fd868a0c71..3da5633f649f075fe258d89dca0cca43dc4257c6 100644 (file)
@@ -61,6 +61,3 @@ class CityDaemonBootstrap???Filter extends BaseCityFilter implements Filterable
                $this->partialStub('Please implement this step.');
        }
 }
-
-// [EOF]
-?>
index c603643c890e2fd5953a81b655868516f3d28a8e..9e9e75ecbcc1bb28927061bd2dace9402ab1469c 100644 (file)
@@ -61,6 +61,3 @@ class CityDaemonBootstrapExtraBootstrappingFilter extends BaseCityFilter impleme
                $cityInstance->doBootstrapping();
        }
 }
-
-// [EOF]
-?>
index cb0afcac2a9aef9a115bc90210b622adc63adc90..54246ae3e7dae308746930ba6e5a6b6ce097a0e1 100644 (file)
@@ -62,6 +62,3 @@ class CityDaemonBootstrap???Filter extends BaseCityFilter implements Filterable
                $this->partialStub('Please implement this step.');
        }
 }
-
-// [EOF]
-?>
index 7a573f852b2049b377143c5006d89860033d1b87..2b5edb6b325614ae98090a0b185088c48f67e9c4 100644 (file)
@@ -61,6 +61,3 @@ class CityDaemonBootstrapInitDaemonFilter extends BaseCityFilter implements Filt
                $cityInstance->bootstrapInitCityDaemon();
        }
 }
-
-// [EOF]
-?>
index 6a1f54a94562435cca38662b32683bd6c9a91050..9cde6ee910afd95bb50766f62e5269514d26744c 100644 (file)
@@ -58,6 +58,3 @@ class CityDaemon???Filter extends BaseCityFilter implements Filterable {
                $this->partialStub('Please implement this method.');
        }
 }
-
-// [EOF]
-?>
index 86517cfa32ced595d8a92b6a61978a0b6bea6726..acef3188b65d18da7639493621b6ef221acbf292 100644 (file)
@@ -67,6 +67,3 @@ class CityDaemonInitializationFilter extends BaseCityFilter implements Filterabl
                /* DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('CITY-INIT-FILTER[' . __METHOD__ . ':' . __LINE__ . ']: City daemon has been added to registry.');
        }
 }
-
-// [EOF]
-?>
index a215e82edf9bfeabfb72cb6e2b99fb2dba75e9d3..8ec734fdcdb63b9f158c1a4710aebbc7de2dfd1f 100644 (file)
@@ -66,6 +66,3 @@ class CityDaemonPhpRequirementsFilter extends BaseCityFilter implements Filterab
                } // END - if
        }
 }
-
-// [EOF]
-?>
index 3daa519668a377f6218f6bf349625417d98aa8e9..952df5c4eb584989dd953a583e2cedc540146ef0 100644 (file)
@@ -62,6 +62,3 @@ class CityDaemonWelcomeTeaserFilter extends BaseCityFilter implements Filterable
                $cityInstance->outputConsoleTeaser();
        }
 }
-
-// [EOF]
-?>
index b2e975df25cbe576a7657a6f41e1ad6ea2782e4b..88871ee0e257490f94f3bb85afd039ecf3b1e7a5 100644 (file)
@@ -62,6 +62,3 @@ class City!!!???Filter extends BaseCityFilter implements Filterable {
                $this->partialStub('Please implement this step.');
        }
 }
-
-// [EOF]
-?>
index a16e68a5b7a93a2e7edd5a02d4af675ed20e8de1..8f369565a333ce1765cf2df7ffd57879eb948e88 100644 (file)
@@ -106,6 +106,3 @@ class BaseCityFilter extends BaseFilter {
                $packageInstance->getStackInstance()->pushNamed(NetworkPackage::STACKER_NAME_PROCESSED_MESSAGE, $messageArray);
        }
 }
-
-// [EOF]
-?>
index 8fcbc8d0532a597d048a465e91f2f964835ebb67..f1b246dfa7e69544fbb6ad212b9b7198569d689a 100644 (file)
@@ -62,6 +62,3 @@ class CityDaemonShutdown???Filter extends BaseCityFilter implements Filterable {
                $this->partialStub('Please implement this step.');
        }
 }
-
-// [EOF]
-?>
index a8f89fa27111bbf564d38026eb8ecf9e1f84157f..ecca1661b9f0be63c4ad9fb41a9482d1999e6066 100644 (file)
@@ -63,6 +63,3 @@ class CityDaemonShutdownCityFilter extends BaseCityFilter implements Filterable
                $cityInstance->doShutdown();
        }
 }
-
-// [EOF]
-?>
index d55708534596d13272d6ccd66802c637bfaf02e6..03b46711473b4472fe3afd6161357da167dd3a90 100644 (file)
@@ -62,6 +62,3 @@ class CityDaemonShutdownTaskHandlerFilter extends BaseCityFilter implements Filt
                $handlerInstance->doShutdown();
        }
 }
-
-// [EOF]
-?>
index 1175ae8cf4408d636099485f6f96adb695522670..ce13fe520aab0f10f2c4346967dbfeb11d4ac425 100644 (file)
@@ -88,6 +88,3 @@ class CityDaemonTaskHandlerInitializerFilter extends BaseCityFilter implements F
                $cityInstance->addExtraTasks($handlerInstance);
        }
 }
-
-// [EOF]
-?>
index f8c3fa5cf7331e4187daf3466de9e174e42f5cbd..fc7609701005c73f55001e20c1da73df4a15c672 100644 (file)
@@ -110,6 +110,3 @@ class CityNameVerifierFilter extends BaseFilter implements Filterable {
                return $alreadyTaken;
        }
 }
-
-// [EOF]
-?>
index b29428d2c78aebd582300f1b885fa4adf40e3113..11a938ffb1eb8f55ff812568385e831d9aab6cd4 100644 (file)
@@ -135,6 +135,3 @@ class CityGuestLogin extends BaseFrameworkSystem implements LoginableUser, Regis
                } // END - if
        }
 }
-
-// [EOF]
-?>
index 5c34e247fa8964a4c0a0652fdabaecebf472ad16..a0bf3b732a6d7e801b2504bccefc5164d9054abf 100644 (file)
@@ -143,6 +143,3 @@ class CityUserLogin extends BaseFrameworkSystem implements LoginableUser, Regist
                } // END - if
        }
 }
-
-// [EOF]
-?>
index 8510cde7e4446921600afe7b199a13bbca42ae53..0eb60601b03a3188e0b74f16d56cfc8944f8aae3 100644 (file)
@@ -125,6 +125,3 @@ class CityManager extends BaseManager implements ManageableCity {
                $this->partialStub('Please implement this method.');
        }
 }
-
-// [EOF]
-?>
index 1d90782d473908331a31157453b9aa0155e623ab..b2bc7753fbea99bf2fcacfb139a166120aa5051b 100644 (file)
@@ -51,6 +51,3 @@ class CityDistrictsManager extends BaseFrameworkSystem implements ManageableCity
                return $managerInstance;
        }
 }
-
-// [EOF]
-?>
index 5a4631f08ba3ade90d1e8e6a718455ca08b9824e..d1585587e363dc9d9fd84a80d31d5e5c37ab1451 100644 (file)
@@ -51,6 +51,3 @@ class CityLotsManager extends BaseFrameworkSystem implements ManageableCityLots,
                return $managerInstance;
        }
 }
-
-// [EOF]
-?>
index 28ddae20366c39c2907d82635fd3b6a6476d8d31..6e540962b92d24bb35a71f29e34bd47a91309af7 100644 (file)
@@ -97,6 +97,3 @@ class CitySectionsManager extends BaseFrameworkSystem implements ManageableCityS
                } // END - foreach
        }
 }
-
-// [EOF]
-?>
index 42511ac8bc241029edfc33afecba41f2814f31a5..b8c291d83f0a9c95b93e62d93b1794abb8299790 100644 (file)
@@ -45,6 +45,3 @@ class ???Manager extends BaseFrameworkSystem implements Manageable???, Registera
                return $managerInstance;
        }
 }
-
-// [EOF]
-?>
index 50cfdd9f972b46fec88b0a4e503166c1f95e34cd..1f281bccb868999ee241aace18b619b31425fc49 100644 (file)
@@ -33,6 +33,3 @@ class BaseManager extends BaseCitySystem implements Manageable, Registerable {
                parent::__construct($className);
        }
 }
-
-// [EOF]
-?>
index 7e109cd534dd57bc88fbc3e3d607f020cb81f382..6fa4849ddf534fb82dfc70c5b6317badc2ecb49f 100644 (file)
@@ -105,6 +105,3 @@ class RegionManager extends BaseManager implements ManageableRegion {
                return $resultInstance;
        }
 }
-
-// [EOF]
-?>
index 9f30bc2c7650074063878bd157db8250c0c8b0ac..76e4a875f726e5413ae460c48a188e6f93a0829f 100644 (file)
@@ -105,6 +105,3 @@ class RegionManager extends BaseManager implements ManageableRegion {
                return $resultInstance;
        }
 }
-
-// [EOF]
-?>
index 98deeb4aec1981e91d22e9f037ce781000f898a8..98817f265cb7cc647558afcaaba0f26379b77441 100644 (file)
@@ -62,6 +62,3 @@ class RegionMapManager extends BaseManager implements ManageableRegionMap {
                die('!ok');
        }
 }
-
-// [EOF]
-?>
index e6966dd2660360497ee4e3582cac9dd1b7c8e88f..84450b4765e3ef43ba46e4e2fc19265ba1a2475c 100644 (file)
@@ -45,6 +45,3 @@ class City???Menu extends BaseMenu implements RenderableMenu {
                return $menuInstance;
        }
 }
-
-// [EOF]
-?>
index f6bf7b8a5b9716347200574d22c05a7f8b332d39..3a020361b5379db2889d5b1683d6479a9f4699e5 100644 (file)
@@ -45,6 +45,3 @@ class CityConfirmMenu extends BaseMenu implements RenderableMenu {
                return $menuInstance;
        }
 }
-
-// [EOF]
-?>
index b1975ad099a3af1f6f35e53b466b2999cd57e3f7..1e0b943a396c67dc3ac257ea94b1209fc8a51db7 100644 (file)
@@ -45,6 +45,3 @@ class CityHomeMenu extends BaseMenu implements RenderableMenu {
                return $menuInstance;
        }
 }
-
-// [EOF]
-?>
index b5d5068dd8ba40feb149d5343cc4a77cf3c33f8e..52a590378d8cf8b6c98aa158816a2e2575a7add4 100644 (file)
@@ -45,6 +45,3 @@ class CityLoginAreaMenu extends BaseMenu implements RenderableMenu {
                return $menuInstance;
        }
 }
-
-// [EOF]
-?>
index 228bcc08720ddac84d417c68bde1f14eb4dd8810..25125fc2d9bb4c04b1faa9c8d1267d355e2f6e8c 100644 (file)
@@ -45,6 +45,3 @@ class CityLoginFailedMenu extends BaseMenu implements RenderableMenu {
                return $menuInstance;
        }
 }
-
-// [EOF]
-?>
index d9e8c2a06a66ae6ddd9d443d5fb85c6c5c959dd1..e2be32c4ec5adf9f79ad782107dc311fc0f3a4ce 100644 (file)
@@ -45,6 +45,3 @@ class CityLoginMenu extends BaseMenu implements RenderableMenu {
                return $menuInstance;
        }
 }
-
-// [EOF]
-?>
index 9ec8861a334b93db92b38c0a753250b2c41d6d05..7d3e85efc83a16f026f421a7ccba33da718db002 100644 (file)
@@ -45,6 +45,3 @@ class CityLogoutMenu extends BaseMenu implements RenderableMenu {
                return $menuInstance;
        }
 }
-
-// [EOF]
-?>
index 50bb5766227672c313db423ba66ee3c47b63e17b..a1182ce924387fa36fcc90da80a7f99ef6fb7070 100644 (file)
@@ -45,6 +45,3 @@ class CityRegisterMenu extends BaseMenu implements RenderableMenu {
                return $menuInstance;
        }
 }
-
-// [EOF]
-?>
index 2a56211a18a7d08198ab1887405d7d8a2561152c..06d04b28e9f824c4422fc5dcfd46cc370c57cae4 100644 (file)
@@ -45,6 +45,3 @@ class CityStatusMenu extends BaseMenu implements RenderableMenu {
                return $menuInstance;
        }
 }
-
-// [EOF]
-?>
index 4cbbe017bf16373e27e942050ec573ba0a55a2d1..d52f478c74d9cf36effdeb01f4850c745ef8f716 100644 (file)
@@ -45,6 +45,3 @@ class CityGovernmentFailedAreaMenu extends BaseMenu implements RenderableMenu {
                return $menuInstance;
        }
 }
-
-// [EOF]
-?>
index b64264679ca2a19ba3344cab9e309d277ceb5117..4f17a7b19065bbcc2ecc1a9f974bd1a334bab581 100644 (file)
@@ -64,6 +64,3 @@ class CityConsoleCommandResolver extends BaseCommandResolver implements CommandR
                return $resolverInstance;
        }
 }
-
-// [EOF]
-?>
index f19b6c7d9e0440ffc708769be1113eef1fdd1b63..ea492be5b7aa2fa63d66077c6fbfd18d4e087fb8 100644 (file)
@@ -64,6 +64,3 @@ class CityHtmlCommandResolver extends BaseCommandResolver implements CommandReso
                return $resolverInstance;
        }
 }
-
-// [EOF]
-?>
index 544a1e414d1554ebccfc485acee45be8e83ad8db..a4b6d8a683a661dd78abf99658adc940d704f568 100644 (file)
@@ -67,6 +67,3 @@ class CityConsoleControllerResolver extends BaseControllerResolver implements Co
                return $resolverInstance;
        }
 }
-
-// [EOF]
-?>
index 06fc2415e7199ba4f93478cd8a7ce00f0bee3554..45168d72e388416313bcf45c08dae65e3ba7ac6c 100644 (file)
@@ -67,6 +67,3 @@ class CityHtmlControllerResolver extends BaseControllerResolver implements Contr
                return $resolverInstance;
        }
 }
-
-// [EOF]
-?>
index e837d972f62b01d573982d7ac7a4713f67d82474..de17cf35500907a37599a725460b9008ec54cdd4 100644 (file)
@@ -67,6 +67,3 @@ class CityImageControllerResolver extends BaseControllerResolver implements Cont
                return $resolverInstance;
        }
 }
-
-// [EOF]
-?>
index 520e0310b5052b4546db2a21a45bd1b0b86b8c67..bb3473a9b631f7eef93acae9aff12e25d5cbd4d2 100644 (file)
@@ -51,6 +51,3 @@ class CityActiveState extends BaseCityState implements Stateable {
                return $stateInstance;
        }
 }
-
-// [EOF]
-?>
index 6051e65bdba2dc2accf84806b7a133455509c20c..a81ff3424943efb23f2e67dc754ef78589521fa9 100644 (file)
@@ -48,6 +48,3 @@ class City???State extends BaseCityState implements Stateable {
                return $stateInstance;
        }
 }
-
-// [EOF]
-?>
index 14d707c09e0fd3100d1666552fd51b8144706416..56e57cb1cdd61a27ef91f357ac9b616c80f2722c 100644 (file)
@@ -63,6 +63,3 @@ class BaseCityState extends BaseState {
                } // END - if
        }
 }
-
-// [EOF]
-?>
index 77b4737a9dd80ec5bb263b980ca7171ab96dfca9..32ec04bfe54c7aa95200a0201e5308a455ff8762 100644 (file)
@@ -70,6 +70,3 @@ class CityInitState extends BaseCityState implements Stateable {
                CityStateFactory::createCityStateInstanceByName('active');
        }
 }
-
-// [EOF]
-?>
index f4343d21b870fc278b6c5a6edc56aea8220f763f..92550f6aa364b51e26610d71bef42edbf299ca49 100644 (file)
@@ -57,6 +57,3 @@ class BaseCityTask extends BaseTask {
                $this->cityInstance = $cityInstance;
        }
 }
-
-// [EOF]
-?>
index 5f14806b6bd4569fba4593559952d00b6953f7ad..b536f751b419c0d994900a39a5bcee6d531db387 100644 (file)
@@ -90,6 +90,3 @@ class CityDaemonBuildingGrowthTask extends BaseCityTask implements Taskable, Vis
                self::createDebugInstance(__CLASS__)->debugOutput('TASK[' . __METHOD__ . ':' . __LINE__ . ']: Shutting down...');
        }
 }
-
-// [EOF]
-?>
index b0984b9467e7f048d3ab7c3e7aafee4284c39a8a..a230088d4c22bacf2cdac8ac1878418a83b4934d 100644 (file)
@@ -77,6 +77,3 @@ class CityDaemon???Task extends BaseTask implements Taskable, Visitable {
                self::createDebugInstance(__CLASS__)->debugOutput('TASK[' . __METHOD__ . ':' . __LINE__ . ']: Shutting down...');
        }
 }
-
-// [EOF]
-?>
index 2e017f1dab2b2a3cd256de4cc4d67ea9598283c3..5b749ca21d330bc98729cad1d2a459c8d2d4b53e 100644 (file)
@@ -90,6 +90,3 @@ class CityDaemonHouseholdGrowthTask extends BaseCityTask implements Taskable, Vi
                self::createDebugInstance(__CLASS__)->debugOutput('TASK[' . __METHOD__ . ':' . __LINE__ . ']: Shutting down...');
        }
 }
-
-// [EOF]
-?>
index ef4d6a121c305c5c25f130c097143b9807307d4e..fa7db40e3f2a70456446c35518877cc4c2044c20 100644 (file)
@@ -90,6 +90,3 @@ class CityDaemonMapExpanderTask extends BaseCityTask implements Taskable, Visita
                self::createDebugInstance(__CLASS__)->debugOutput('TASK[' . __METHOD__ . ':' . __LINE__ . ']: Shutting down...');
        }
 }
-
-// [EOF]
-?>
index 0d406935ba633dadab0d8f728d90ae642b3ca032..ac4c73cfcab471e5fa61c8c6e6d71209f0127bc7 100644 (file)
@@ -29,6 +29,3 @@ $cfg = FrameworkConfiguration::getSelfInstance();
 
 // CFG: CITY-FOO
 $cfg->setConfigEntry('city_foo', 'foo');
-
-// [EOF]
-?>
index c07d84a5f666e91fa92cf1647d48a3b207432742..234f055e31366ab353e1a3c61267a7bb11454458 100644 (file)
@@ -1,4 +1,7 @@
 <?php
+// Import framework stuff
+use Org\Mxchange\CoreFramework\Bootstrap\FrameworkBootstrap;
+
 /**
  * Configuration entries for this application only
  *
@@ -22,7 +25,7 @@
  */
 
 // Some hub-specific configuration like port hostname where we will listen, etc.
-$cfg = FrameworkConfiguration::getSelfInstance();
+$cfg = FrameworkBootstrap::getConfigurationInstance();
 
 /******************************************************************************
  *                                  General                                   *
@@ -590,6 +593,3 @@ $cfg->setConfigEntry('city_max_initial_up_expansion', 5);
 
 // CFG: CITY-MAX-INITIAL-DOWN-EXPANSION
 $cfg->setConfigEntry('city_max_initial_down_expansion', 3);
-
-// [EOF]
-?>
index bdfe8797ba78991d89c6975dc6b086deb49c4337..7d6dceec926b2c790d8a6cc64b29a822d57f79e9 100644 (file)
@@ -1,43 +1,2 @@
 <?php
-/**
- * Application data
- *
- * Please remember that this include file is being loaded *before* the class
- * loader is loading classes from "exceptions", "interfaces" and "main"!
- *
- * @author             Roland Haeder <webmaster@shipsimu.org>
- * @version            0.0.0
- * @copyright  Copyright (c) 2015, 2016 City Developer Team
- * @license            GNU GPL 3.0 or any newer version
- * @link               http://www.shipsimu.org
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
-
-// Get config instance
-$cfg = FrameworkConfiguration::getSelfInstance();
-
-// Get an instance of the helper
-$app = call_user_func_array(
-       array($cfg->getConfigEntry('app_helper_class'), 'getSelfInstance'),
-       array()
-);
-
-// Set application name and version
-$app->setAppName('Simple City Growth Simulation');
-$app->setAppVersion('0.0.0');
-$app->setAppShortName('city');
-
-// [EOF]
-?>
+// @DEPRECATED
index 2b78507d825bf2a4a7088fa8b025120d6b23a773..76a13390809712cf4d5e5d5286485a491646ec60 100644 (file)
@@ -23,6 +23,3 @@
 
 // Set error reporting
 error_reporting(E_ALL | E_STRICT);
-
-// [EOF]
-?>
index a3d54a06ba03171bde588cb738633c2ef7665e4a..3538bd31dbe85bcf1a5ef49348df432255e9408e 100644 (file)
@@ -1,10 +1,14 @@
 <?php
+// Import framework stuff
+use Org\Mxchange\CoreFramework\Generic\FrameworkException;
+use Org\Mxchange\CoreFramework\Object\BaseFrameworkSystem;
+
 /**
  * An include file for setting up the exception handler of test suite
  *
  * @author             Roland Haeder <webmaster@shipsimu.org>
- * @version            0.0
- * @copyright  Copyright (c) 2015, 2016 City Developer Team
+ * @version            0.0.0
+ * @copyright  Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
  * @license            GNU GPL 3.0 or any newer version
  *
  * This program is free software: you can redistribute it and/or modify
@@ -22,9 +26,9 @@
  */
 
 // The node's own exception handler
-function city_exception_handler ($exceptionInstance) {
+function tests_exception_handler ($exceptionInstance) {
        // Is it an object and a valid instance?
-       if ((is_object($exceptionInstance)) && ($exceptionInstance instanceof FrameworkException)) {
+       if ((is_object($exceptionInstance)) && ($exceptionInstance instanceof Exception)) {
                // Init variable
                $backTrace = '';
 
@@ -73,9 +77,9 @@ Backtrace:
 --------------------------------------------------------------------------------
 %s
 --------------------------------------------------------------------------------\n",
-                       trim(html_entity_decode(strip_tags($exceptionInstance->__toString()))),
+                       trim(html_entity_decode(strip_tags(get_class($exceptionInstance)))),
                        trim(html_entity_decode(strip_tags($exceptionInstance->getMessage()))),
-                       $exceptionInstance->getHexCode(),
+                       ($exceptionInstance instanceof FrameworkException ? $exceptionInstance->getHexCode() : '0x' . bin2hex($exceptionInstance->getCode())),
                        $exceptionInstance->getFile(),
                        $exceptionInstance->getLine(),
                        trim($backTrace)
@@ -83,16 +87,21 @@ Backtrace:
 
                // Output the message
                print($message);
+       } elseif (is_object($exceptionInstance)) {
+               // Output more details
+               printf('exceptionInstance=%s', print_r($exceptionInstance, true));
        } else {
-               // Invalid exception instance detected! Do *only* throw exceptions that
-               // extends our own exception 'FrameworkException' to get such nice
-               // outputs like above.
-               print('exceptionInstance[]=' . gettype($exceptionInstance) . ' is invalid! Please inform the City developer team.');
+               /*
+                * Invalid exception instance detected! Do *only* throw exceptions that
+                * extends our own exception 'FrameworkException' to get such nice
+                * outputs like above.
+                */
+               printf('exceptionInstance[]=%s is invalid! Please inform the core developer team.' . PHP_EOL, gettype($exceptionInstance));
        }
 }
 
 // Error handler
-function __errorHandler ($errno, $errstr, $errfile, $errline, array $errcontext) {
+function tests_error_handler ($errno, $errstr, $errfile, $errline, array $errcontext) {
        // Construct the message
        $message = sprintf('File: %s, Line: %s, Code: %s, Message: %s',
                basename($errfile),
@@ -106,7 +115,7 @@ function __errorHandler ($errno, $errstr, $errfile, $errline, array $errcontext)
 } // END - function
 
 // Assertion handler
-function __assertHandler ($file, $line, $code) {
+function tests_assert_handler ($file, $line, $code) {
        // Empty code?
        if ($code === '') {
                $code = '<em>Unknown</em>';
@@ -120,7 +129,6 @@ function __assertHandler ($file, $line, $code) {
        );
 
        // Log assert
-       die('message='.$message);
        syslog(LOG_WARNING, $message);
 
        // Throw an exception here
@@ -128,17 +136,14 @@ function __assertHandler ($file, $line, $code) {
 } // END - function
 
 // Set error handler
-//set_error_handler('__errorHandler');
+//set_error_handler('tests_error_handler');
 
 // Set the new handler
-set_exception_handler('city_exception_handler');
+set_exception_handler('tests_exception_handler');
 
 // Init assert handling
-assert_options(ASSERT_ACTIVE    , TRUE);
-assert_options(ASSERT_WARNING   , FALSE);
-assert_options(ASSERT_BAIL      , TRUE);
-assert_options(ASSERT_QUIET_EVAL, FALSE);
-assert_options(ASSERT_CALLBACK  , '__assertHandler');
-
-// [EOF]
-?>
+assert_options(ASSERT_ACTIVE    , true);
+assert_options(ASSERT_WARNING   , false);
+assert_options(ASSERT_BAIL      , true);
+assert_options(ASSERT_QUIET_EVAL, false);
+assert_options(ASSERT_CALLBACK  , 'tests_assert_handler');
index f6b588e53a17e93984fff6c73aa982ec96af7522..7d6dceec926b2c790d8a6cc64b29a822d57f79e9 100644 (file)
@@ -1,38 +1,2 @@
 <?php
-/**
- * Application initializer
- *
- * Please remember that this include file is being loaded *before* the class
- * loader is loading classes from "exceptions", "interfaces" and "main"!
- *
- * @author             Roland Haeder <webmaster@shipsimu.org>
- * @version            0.0
- * @copyright  Copyright (c) 2015, 2016 City Developer Team
- * @license            GNU GPL 3.0 or any newer version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
-
-// Get config instance
-$cfg = FrameworkConfiguration::getSelfInstance();
-
-// Initialize output system, you can use any class that expands BaseFrameworkSystem
-ApplicationHelper::createDebugInstance('ApplicationHelper');
-
-// This application needs a database connection then we have to simply include
-// the inc/database.php script
-require($cfg->getConfigEntry('base_path') . 'inc/database.php');
-
-// [EOF]
-?>
+// @DEPRECATED
index 349458cb04ebbb35f8fcaa8b191de41dc98724b7..75c3d2e2096bf82abd13897e1c8a4b17100286e0 100644 (file)
@@ -78,6 +78,3 @@ interface CityInformationWrapper extends DatabaseWrapper {
         */
        function getAllCityIds ();
 }
-
-// [EOF]
-?>
index 3f0b41e60f28d92436e43d2f1d564a09f16a3fd0..9852f2f2886d4fa2d14f46fa5bdbc328ad37ef5b 100644 (file)
@@ -30,6 +30,3 @@ interface CityDistrictsWrapper extends DatabaseWrapper {
         */
        function ifCityHasDistricts ($cityId);
 }
-
-// [EOF]
-?>
index 652ccfc91da046e420841c64a93d69c775466420..a053c7e020e35268257723960a54e8770f90b5a9 100644 (file)
@@ -30,6 +30,3 @@ interface CityLotsWrapper extends DatabaseWrapper {
         */
        function ifCityHasLots ($cityId);
 }
-
-// [EOF]
-?>
index 9636cd2dfc092029ffc26cd9a57e66d33ac639c8..1587515c2705fff28c19a627e90a10c4ff648fd8 100644 (file)
@@ -39,6 +39,3 @@ interface CitySectionsWrapper extends DatabaseWrapper {
         */
        function doInitialCityExpansion ($cityId);
 }
-
-// [EOF]
-?>
index 494f7c79b9b7f7002f3b2d7ab6abbeb19f83f0ae..f605e0dedc03c385f9e55e626ce8e6935587f72a 100644 (file)
@@ -53,6 +53,3 @@ interface RegionInformationWrapper extends DatabaseWrapper {
         */
        function createRegionByName ($regionName);
 }
-
-// [EOF]
-?>
index 805f91d1f89e745a619386fad52d7f8572bc96ce..99b8962e2cfc0e62a3c5fb7557a2c579f3bd0923 100644 (file)
@@ -23,6 +23,3 @@
  */
 interface RegionMapWrapper extends DatabaseWrapper {
 }
-
-// [EOF]
-?>
index 76aecbc8e4dedf1043bee00b4e0da06ca520ea39..c3256398d3bb32b34bac738af44de3ac37667a06 100644 (file)
@@ -85,6 +85,3 @@ interface CityHelper extends Helper, AddableCriteria {
         */
        function isMapPendingExpansion ();
 }
-
-// [EOF]
-?>
index 60b577802f7b968674926ef9b5f6e04e83d39523..0055983115fd9e48d9dd8958e824c56ec6ae5745 100644 (file)
@@ -53,6 +53,3 @@ interface ManageableCity extends Manageable {
         */
        function renderCityMap (HelpableTemplate $helperInstance);
 }
-
-// [EOF]
-?>
index 6089ee2de034cd046244fd0329d86ec577286003..8e7a7bedf8b17b4c449afb15957c071ab3c58b00 100644 (file)
@@ -23,6 +23,3 @@
  */
 interface ManageableCityLots extends ManageableCityEntities {
 }
-
-// [EOF]
-?>
index 96ac93452f92e25572fe2afd6c5f313d02486d14..a373f4262db9840168d56d8b7a3b7177865af857 100644 (file)
@@ -36,6 +36,3 @@ interface ManageableCitySections extends ManageableCityEntities {
         */
        function expandMaps ();
 }
-
-// [EOF]
-?>
index 08adc563c6619aa6154f4b0bced036dd25664805..48d9b59eb2df226a3eca1ce999dd577d5b4da4b9 100644 (file)
@@ -23,6 +23,3 @@
  */
 interface Manageable extends FrameworkInterface {
 }
-
-// [EOF]
-?>
index 20fbb3f48d796666524f04e7263ce13693785256..ac173dd1165629df7cbeda516dfedec3ad095be4 100644 (file)
@@ -44,6 +44,3 @@ interface ManageableRegion extends Manageable {
         */
        function createFirstRegion ();
 }
-
-// [EOF]
-?>
index 39261a76e43894693a97ad1cca4eb8ea0052910f..b46c0bb825a39e06ce54e163e589ebd8a0709410 100644 (file)
@@ -31,6 +31,3 @@ interface ManageableRegionMap extends Manageable {
         */
        function createRegionMapByResult (SearchableResult $resultInstance);
 }
-
-// [EOF]
-?>
index aa08c50e9bcd376e7a92aa8dcdda13dba461d9a9..7d6dceec926b2c790d8a6cc64b29a822d57f79e9 100644 (file)
@@ -1,28 +1,2 @@
 <?php
-/**
- * The application's class loader
- *
- * @author             Roland Haeder <webmaster@shipsimu.org>
- * @version            0.0
- * @copyright  Copyright (c) 2015, 2016 City Developer Team
- * @license            GNU GPL 3.0 or any newer version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
-
-// Scan for application's classes, exceptions and interfaces
-ClassLoader::scanApplicationClasses();
-
-// [EOF]
-?>
+// @DEPRECATED
index 837d2033575b1046fc5e8809104e85e526104fc2..7d6dceec926b2c790d8a6cc64b29a822d57f79e9 100644 (file)
@@ -1,57 +1,2 @@
 <?php
-/**
- * The application launcher
- *
- * @author             Roland Haeder <webmaster@shipsimu.org>
- * @version            0.0.0
- * @copyright  Copyright (c) 2015, 2016 City Developer Team
- * @license            GNU GPL 3.0 or any newer version
- * @link               http://www.shipsimu.org
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
-
-// Is there an application helper instance? We need the method main() for
-// maining the application
-$app = call_user_func_array(
-       array(
-               FrameworkConfiguration::getSelfInstance()->getConfigEntry('app_helper_class'), 'getSelfInstance'
-       ), array()
-);
-
-// Some sanity checks
-if ((empty($app)) || (is_null($app))) {
-       // Something went wrong!
-       ApplicationEntryPoint::app_exit(sprintf('[Main:] The application <span class="app_name">%s</span> could not be launched because the helper class <span class="class_name">%s</span> is not loaded.',
-               $application,
-               FrameworkConfiguration::getSelfInstance()->getConfigEntry('app_helper_class')
-       ));
-} elseif (!is_object($app)) {
-       // No object!
-       ApplicationEntryPoint::app_exit(sprintf('[Main:] The application <span class="app_name">%s</span> could not be launched because &#39;app&#39; is not an object.',
-               $application
-       ));
-} elseif (!method_exists($app, FrameworkConfiguration::getSelfInstance()->getConfigEntry('entry_method'))) {
-       // Method not found!
-       ApplicationEntryPoint::app_exit(sprintf('[Main:] The application <span class="app_name">%s</span> could not be launched because the method <span class="method_name">%s</span> is missing.',
-               $application,
-               FrameworkConfiguration::getSelfInstance()->getConfigEntry('entry_method')
-       ));
-}
-
-// Call user function
-call_user_func_array(array($app, FrameworkConfiguration::getSelfInstance()->getConfigEntry('entry_method')), array());
-
-// [EOF]
-?>
+// @DEPRECATED
index 223e4fbf0de2945eb7403a1b58df2bc8ea300ca8..d74d5470f4ebfbf27b7ff5b8e2fe426bc3c7fd8f 100644 (file)
@@ -73,6 +73,3 @@ $helper->flushContent();
 
 // Comment this out if image is done
 //$this->debugInstance();
-
-// [EOF]
-?>
index bf67aa7f8f523dbe907e70de5acff4bfe10a2792..a2f3de3b3add2e142c57adf28ff2ebe63c8f8e1b 100644 (file)
@@ -13,6 +13,3 @@ $helper->setHeight(50);
 
 // Comment this out if image is done
 $this->debugInstance();
-
-// [EOF]
-?>
diff --git a/core b/core
index 3136095b1d2e8c77eefd2eae23d99897ef586e56..d3194bf4fa92124e55cfc596e50abca8e6303944 160000 (submodule)
--- a/core
+++ b/core
@@ -1 +1 @@
-Subproject commit 3136095b1d2e8c77eefd2eae23d99897ef586e56
+Subproject commit d3194bf4fa92124e55cfc596e50abca8e6303944
diff --git a/inc b/inc
deleted file mode 120000 (symlink)
index 1f8dea2..0000000
--- a/inc
+++ /dev/null
@@ -1 +0,0 @@
-core/inc
\ No newline at end of file
index 74d021df5751426487d020a8ec53efe156816280..1e7f1d48f75e9a68e0803bef7bd71d416ff24fa6 100644 (file)
--- a/index.php
+++ b/index.php
@@ -1,4 +1,19 @@
 <?php
+// Own namespace (watch out: core)
+namespace Org\Mxchange\CoreFramework\EntryPoint;
+
+// Import framework stuff
+use Org\Mxchange\CoreFramework\Bootstrap\FrameworkBootstrap;
+use Org\Mxchange\CoreFramework\Factory\ObjectFactory;
+use Org\Mxchange\CoreFramework\Filesystem\FileNotFoundException;
+use Org\Mxchange\CoreFramework\Helper\Application\ApplicationHelper;
+use Org\Mxchange\CoreFramework\Localization\LanguageSystem;
+use Org\Mxchange\CoreFramework\Loader\ClassLoader;
+use Org\Mxchange\CoreFramework\Generic\FrameworkException;
+
+// Import SPL stuff
+use \Exception;
+
 /**
  * The main class with the entry point to the whole application. This class
  * "emulates" Java's entry point call. Additionally it covers local
@@ -9,7 +24,7 @@
  *
  * @author             Roland Haeder <webmaster@shipsimu.org>
  * @version            0.0.0
- * @copyright  Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Core Developer Team
+ * @copyright  Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
  * @license            GNU GPL 3.0 or any newer version
  * @link               http://www.shipsimu.org
  *
@@ -28,9 +43,9 @@
  */
 final class ApplicationEntryPoint {
        /**
-        * Core path
+        * Framework path
         */
-       private static $corePath = '';
+       private static $frameworkPath = '';
 
        /**
         * The application's emergency exit
@@ -42,7 +57,7 @@ final class ApplicationEntryPoint {
         * @return      void
         * @todo        This method is old code and needs heavy rewrite and should be moved to ApplicationHelper
         */
-       public static final function app_exit ($message = '', $code = FALSE, $extraData = '', $silentMode = FALSE) {
+       public static final function exitApplication ($message = '', $code = false, $extraData = '', $silentMode = false) {
                // Is this method already called?
                if (isset($GLOBALS['app_die_called'])) {
                        // Then output the text directly
@@ -50,7 +65,7 @@ final class ApplicationEntryPoint {
                } // END - if
 
                // This method shall not be called twice
-               $GLOBALS['app_die_called'] = TRUE;
+               $GLOBALS['app_die_called'] = true;
 
                // Is a message set?
                if (empty($message)) {
@@ -59,23 +74,23 @@ final class ApplicationEntryPoint {
                } // END - if
 
                // Get config instance
-               $configInstance = FrameworkConfiguration::getSelfInstance();
+               $configInstance = FrameworkBootstrap::getConfigurationInstance();
 
                // Do we have debug installation?
-               if (($configInstance->getConfigEntry('product_install_mode') == 'productive') || ($silentMode === TRUE)) {
+               if (($configInstance->getConfigEntry('product_install_mode') == 'productive') || ($silentMode === true)) {
                        // Abort here
                        exit();
                } // END - if
 
                // Get some instances
-               $tpl = FrameworkConfiguration::getSelfInstance()->getConfigEntry('html_template_class');
+               $tpl = $configInstance->getConfigEntry('html_template_class');
                $languageInstance = LanguageSystem::getSelfInstance();
 
                // Initialize template instance here to avoid warnings in IDE
                $templateInstance = NULL;
 
                // Get response instance
-               $responseInstance = ApplicationHelper::getSelfInstance()->getResponseInstance();
+               $responseInstance = FrameworkBootstrap::getResponseInstance();
 
                // Is the template engine loaded?
                if ((class_exists($tpl)) && (is_object($languageInstance))) {
@@ -84,7 +99,7 @@ final class ApplicationEntryPoint {
                                // Get the template instance from our object factory
                                $templateInstance = ObjectFactory::createObjectByName($tpl);
                        } catch (FrameworkException $e) {
-                               exit(sprintf("[Main:] Could not initialize template engine for reason: <span class=\"exception_reason\">%s</span>",
+                               exit(sprintf('[Main:] Could not initialize template engine for reason: <span class="exception_reason">%s</span>',
                                        $e->getMessage()
                                ));
                        }
@@ -105,7 +120,7 @@ final class ApplicationEntryPoint {
                                } // END - if
 
                                // Add the traceback path to the final output
-                               $backtrace .= sprintf("<span class=\"backtrace_file\">%s</span>:%d, <span class=\"backtrace_function\">%s(%d)</span><br />\n",
+                               $backtrace .= sprintf('<span class="backtrace_file">%s</span>:%d, <span class="backtrace_function">%s(%d)</span><br />' . PHP_EOL,
                                        basename($trace['file']),
                                        $trace['line'],
                                        $trace['function'],
@@ -117,7 +132,7 @@ final class ApplicationEntryPoint {
                        $applicationInstance = NULL;
 
                        // Is the class there?
-                       if (class_exists('ApplicationHelper')) {
+                       if (class_exists('Org\Mxchange\CoreFramework\Helper\Application\ApplicationHelper')) {
                                // Get application instance
                                $applicationInstance = ApplicationHelper::getSelfInstance();
 
@@ -150,7 +165,7 @@ final class ApplicationEntryPoint {
 
                                // Flush the response
                                $responseInstance->flushBuffer();
-                       } catch (FileIoException $e) {
+                       } catch (FileNotFoundException $e) {
                                // Even the template 'emergency_exit' wasn't found so output both message
                                exit($message . ', exception: ' . $e->getMessage());
                        }
@@ -166,52 +181,106 @@ final class ApplicationEntryPoint {
        }
 
        /**
-        * Determines the correct absolute path for all includes only once per run.
-        * Other calls of this method are being "cached".
+        * Determines the correct absolute path for the framework. A set of common
+        * paths is being tested (first most common for applications, second when
+        * core tests are being executed and third/forth if the framework has been
+        * cloned there).
         *
-        * @return      $corePath       Base path (core) for all includes
+        * @return      $frameworkPath  Path for framework
         */
-       protected static final function detectCorePath () {
+       public static final function detectFrameworkPath () {
                // Is it not set?
-               if (empty(self::$corePath)) {
-                       // Auto-detect our core path
-                       self::$corePath = str_replace("\\", '/', dirname(__FILE__));
+               if (empty(self::$frameworkPath)) {
+                       // Auto-detect core path (first application-common)
+                       foreach (array('core', __DIR__, '/usr/local/share/php/core', '/usr/share/php/core') as $possiblePath) {
+                               // Create full path for testing
+                               $realPath = realpath($possiblePath);
+
+                               // Debug message
+                               //* NOISY-DEBUG: */ printf('[%s:%d]: realPath[%s]=%s' . PHP_EOL, __METHOD__, __LINE__, gettype($realPath), $realPath);
+
+                               // Is it false?
+                               if ($realPath === false) {
+                                       // Then, not found.
+                                       continue;
+                               } // END - if
+
+                               // Append framework path
+                               $frameworkPath = sprintf('%s%sframework%s', $realPath, DIRECTORY_SEPARATOR, DIRECTORY_SEPARATOR);
+
+                               // First create full-qualified file name (FQFN) to framework/config-global.php
+                               $configFile = $frameworkPath . 'config-global.php';
+
+                               // Debug message
+                               //* NOISY-DEBUG: */ printf('[%s:%d]: configFile=%s' . PHP_EOL, __METHOD__, __LINE__, $configFile);
+
+                               // Is it readable?
+                               if (is_readable($configFile)) {
+                                       // Found one
+                                       self::$frameworkPath = $frameworkPath;
+
+                                       // Abort here
+                                       break;
+                               } // END - if
+                       } // END - foreach
+
+                       // Able to find?
+                       if (!is_dir(self::$frameworkPath)) {
+                               // Is no directory
+                               throw new Exception('Cannot find framework.');
+                       } // END - if
                } // END - if
 
                // Return it
-               return self::$corePath;
+               return self::$frameworkPath;
        }
 
        /**
-        * The application's main entry point. This class isolates some local
+        * Getter for root path
+        *
+        * @return      $rootPath       Root path
+        */
+       public static function getRootPath () {
+               // Get __DIR__, really simple and no detection
+               return __DIR__;
+       }
+
+       /**
+        * The framework's main entry point. This class isolates some local
         * variables which shall not become visible to outside because of security
-        * concerns. We are doing this here to "emulate" the well-known entry
-        * point in Java.
+        * concerns. This is done here to "emulate" the well-known entry point in
+        * Java.
         *
         * @return      void
         */
        public static final function main () {
-               // Load config file
-               require(self::detectCorePath() . '/inc/config.php');
+               // Load bootstrap file
+               require sprintf('%sbootstrap%sbootstrap.inc.php', self::detectFrameworkPath(), DIRECTORY_SEPARATOR);
 
-               // Load all include files
-               require($cfg->getConfigEntry('base_path') . 'inc/includes.php');
+               /*
+                * Initial bootstrap is done, continue with initialization of
+                * framework.
+                */
+               FrameworkBootstrap::initFramework();
 
-               // Include the application selector
-               require($cfg->getConfigEntry('base_path') . 'inc/selector.php');
-       } // END - main()
-} // END - class
+               // Next initialize the detected application
+               FrameworkBootstrap::prepareApplication();
+
+               /*
+                * Last step is to start the application, this will also initialize and
+                * register the application instance in registry.
+                */
+               FrameworkBootstrap::startApplication();
+       }
+}
 
 // Developer mode active? Comment out if no dev!
-define('DEVELOPER', TRUE);
+define('DEVELOPER', true);
 
 // Log all exceptions (only debug! This option can create large error logs)
-//define('LOG_EXCEPTIONS', TRUE);
+//define('LOG_EXCEPTIONS', true);
 
-//* DEBUG: */ xdebug_start_trace();
+//xdebug_start_trace();
 
-// Do not remove the following line:
+// Call above main() method
 ApplicationEntryPoint::main();
-
-// [EOF]
-?>